summaryrefslogtreecommitdiffstats
path: root/karm
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /karm
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'karm')
-rw-r--r--karm/TODO2
-rw-r--r--karm/doc/Mainpage.dox34
-rw-r--r--karm/kaccelmenuwatch.cpp18
-rw-r--r--karm/kaccelmenuwatch.h38
-rw-r--r--karm/karm_part.cpp48
-rw-r--r--karm/karm_part.h30
-rw-r--r--karm/main.cpp2
-rw-r--r--karm/mainwindow.cpp48
-rw-r--r--karm/mainwindow.h28
-rw-r--r--karm/taskview.cpp8
-rw-r--r--karm/taskview.h4
-rw-r--r--karm/taskviewwhatsthis.cpp2
-rw-r--r--karm/taskviewwhatsthis.h2
-rw-r--r--karm/tray.h4
14 files changed, 134 insertions, 134 deletions
diff --git a/karm/TODO b/karm/TODO
index dd4b41a19..e90244549 100644
--- a/karm/TODO
+++ b/karm/TODO
@@ -1,4 +1,4 @@
-* KarmWindow::makeMenus -> export KAction? KarmWindow::contextMenuRequest
+* KarmWindow::makeMenus -> export TDEAction? KarmWindow::contextMenuRequest
* QPopupMenu should be static! put connect( ..contextMenu at the right place
* mainwindow: move tray Q_SIGNALS into tray.cpp add mouse double-click action
* (start new timer, stop old) to "Configure
diff --git a/karm/doc/Mainpage.dox b/karm/doc/Mainpage.dox
index 4bb930f3f..44aae4eea 100644
--- a/karm/doc/Mainpage.dox
+++ b/karm/doc/Mainpage.dox
@@ -12,7 +12,7 @@ up the status bar, and handles many of the signal-to-slot connections. It
holds a pointer to the TaskView and Preferences objects and implements the
%Karm's DCOP interface (defined in KarmDCOPIface).
-TaskView does most of the work in the application. This KListView subclass
+TaskView does most of the work in the application. This TDEListView subclass
sets up the columns in the list, the idle detection timer, the auto save
timer, and the desktop tracker. It starts and stops timers, handles importing
and exporting and displays the edit task dialog in response to user action.
@@ -47,7 +47,7 @@ connections. See \see connections to get an index of what signal is connected to
<tr><td>AddTaskDialog</td> <td>&nbsp;</td> <td>&nbsp;</td> <td>&nbsp;</td> <td>Y </td></tr>
<tr><td>IdleTimer</td> <td>Y </td> <td>Y </td> <td>Y </td> <td>&nbsp;</td></tr>
- <tr><td>KAccelMenuWatch</td> <td>&nbsp;</td> <td>Y </td> <td>&nbsp;</td> <td>Y </td></tr>
+ <tr><td>TDEAccelMenuWatch</td> <td>&nbsp;</td> <td>Y </td> <td>&nbsp;</td> <td>Y </td></tr>
<tr><td>Karm</td> <td>Y </td> <td>Y </td> <td>Y </td> <td>&nbsp;</td></tr>
<tr><td>KarmTray</td> <td>&nbsp;</td> <td>Y </td> <td>Y </td> <td>&nbsp;</td></tr>
<tr><td>KarmWindow</td> <td>&nbsp;</td> <td>&nbsp;</td> <td>Y </td> <td>&nbsp;</td></tr>
@@ -92,7 +92,7 @@ These are the Q_SIGNALS:
<li>IdleTimer::startIdleDetection()
<li>IdleTimer::stopIdleDetection()
<li>IdleTimer::toggleOverAllIdleDetection(bool)
- <li>KAccelMenuWatch::updateMenus()
+ <li>TDEAccelMenuWatch::updateMenus()
<li>Karm::changeTimer(QListViewItem*)
<li>Karm::deleteTask()
<li>Karm::editTask()
@@ -156,7 +156,7 @@ These are the Q_SIGNALS:
<li>AddTaskDialog::enterWhatsThis()
<li>AddTaskDialog::slotAbsolutePressed()
<li>AddTaskDialog::slotRelativePressed()
- <li>KAccelMenuWatch::removeDeadMenu()
+ <li>TDEAccelMenuWatch::removeDeadMenu()
</ol>
*/
@@ -171,7 +171,7 @@ These are the Q_SIGNALS:
<tr><td>AddTaskDialog</td> <td>_relativeRB</td> <td>QRadioButton</td> <td>clicked()</td> <td>this</td> <td>slotRelativePressed</td></tr>
<tr><td>AddTaskDialog</td> <td>whatsThisBU</td> <td>QPushButton</td> <td>clicked()</td> <td>this</td> <td>enterWhatsThis</td></tr>
<tr><td>IdleTimer</td> <td>_timer</td> <td>QTimer</td> <td>timeout()</td> <td>this</td> <td>check</td></tr>
-<tr><td>KAccelMenuWatch</td> <td>menu</td> <td>QPopupMenu</td> <td>destroyed()</td> <td>this</td> <td>removeeDeadMenu</td></tr>
+<tr><td>TDEAccelMenuWatch</td> <td>menu</td> <td>QPopupMenu</td> <td>destroyed()</td> <td>this</td> <td>removeeDeadMenu</td></tr>
<tr><td>Karm</td> <td>this</td> <td>Karm__QListView</td> <td>doubleClicked()</td> <td>this</td> <td>changeTimer</td></tr>
<tr><td>Karm</td> <td>_minuteTimer</td> <td>QTimer</td> <td>timeout()</td> <td>this</td> <td>minuteUpdate</td></tr>
<tr><td>Karm</td> <td>_idleTimer</td> <td>IdleTimer</td> <td>extractTime()</td> <td>this</td> <td>extractTime</td></tr>
@@ -195,18 +195,18 @@ These are the Q_SIGNALS:
<tr><td>KarmWindow</td> <td>_karm</td> <td>Karm</td> <td>timerTick()</td> <td>this</td> <td>updateTime</td></tr>
<tr><td>KarmWindow</td> <td>_karm</td> <td>Karm</td> <td>timerActive()</td> <td>this</td> <td>setActiveIcon</td></tr>
<tr><td>KarmWindow</td> <td>_karm</td> <td>Karm</td> <td>timerInactive()</td> <td>this</td> <td>setInactiveIcon</td></tr>
-<tr><td>KarmWindow</td> <td>KStdAction__quit</td> <td>KAction</td> <td>__()</td> <td>this</td> <td>quit</td></tr>
-<tr><td>KarmWindow</td> <td>KStdAction__print</td> <td>KAction</td> <td>__()</td> <td>this</td> <td>print</td></tr>
-<tr><td>KarmWindow</td> <td>KStdAction__keyBindings</td> <td>KAction</td> <td>__()</td> <td>this</td> <td>keyBindings</td></tr>
-<tr><td>KarmWindow</td> <td>KStdAction__preferences</td> <td>KAction</td> <td>__()</td> <td>_preferences</td> <td>showDialog</td></tr>
-<tr><td>KarmWindow</td> <td>KStdAction__save</td> <td>KAction</td> <td>__()</td> <td>_preferences</td> <td>save</td></tr>
-<tr><td>KarmWindow</td> <td>actionResetSession</td> <td>KAction</td> <td>__()</td> <td>this</td> <td>resetSessionTime</td></tr>
-<tr><td>KarmWindow</td> <td>actionStart</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>startTimer</td></tr>
-<tr><td>KarmWindow</td> <td>actionStop</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>stopCurrentTimer</td></tr>
-<tr><td>KarmWindow</td> <td>actionNew</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>newTask</td></tr>
-<tr><td>KarmWindow</td> <td>actionNewSub</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>newSubTask</td></tr>
-<tr><td>KarmWindow</td> <td>actionDelete</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>deleteTask</td></tr>
-<tr><td>KarmWindow</td> <td>actionEdit</td> <td>KAction</td> <td>__()</td> <td>_karm</td> <td>editTask</td></tr>
+<tr><td>KarmWindow</td> <td>KStdAction__quit</td> <td>TDEAction</td> <td>__()</td> <td>this</td> <td>quit</td></tr>
+<tr><td>KarmWindow</td> <td>KStdAction__print</td> <td>TDEAction</td> <td>__()</td> <td>this</td> <td>print</td></tr>
+<tr><td>KarmWindow</td> <td>KStdAction__keyBindings</td> <td>TDEAction</td> <td>__()</td> <td>this</td> <td>keyBindings</td></tr>
+<tr><td>KarmWindow</td> <td>KStdAction__preferences</td> <td>TDEAction</td> <td>__()</td> <td>_preferences</td> <td>showDialog</td></tr>
+<tr><td>KarmWindow</td> <td>KStdAction__save</td> <td>TDEAction</td> <td>__()</td> <td>_preferences</td> <td>save</td></tr>
+<tr><td>KarmWindow</td> <td>actionResetSession</td> <td>TDEAction</td> <td>__()</td> <td>this</td> <td>resetSessionTime</td></tr>
+<tr><td>KarmWindow</td> <td>actionStart</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>startTimer</td></tr>
+<tr><td>KarmWindow</td> <td>actionStop</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>stopCurrentTimer</td></tr>
+<tr><td>KarmWindow</td> <td>actionNew</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>newTask</td></tr>
+<tr><td>KarmWindow</td> <td>actionNewSub</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>newSubTask</td></tr>
+<tr><td>KarmWindow</td> <td>actionDelete</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>deleteTask</td></tr>
+<tr><td>KarmWindow</td> <td>actionEdit</td> <td>TDEAction</td> <td>__()</td> <td>_karm</td> <td>editTask</td></tr>
<tr><td>Task</td> <td>_timer</td> <td>QTimer</td> <td>timeout()</td> <td>this</td> <td>updateActiveIcon</td></tr>
</table>
diff --git a/karm/karm_part.cpp b/karm/karm_part.cpp
index 36a71043e..f56e02c17 100644
--- a/karm/karm_part.cpp
+++ b/karm/karm_part.cpp
@@ -24,8 +24,8 @@
karmPart::karmPart( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name )
: DCOPObject ( "KarmDCOPIface" ), KParts::ReadWritePart(parent, name),
- _accel ( new KAccel( parentWidget ) ),
- _watcher ( new KAccelMenuWatch( _accel, TQT_TQOBJECT(parentWidget) ) )
+ _accel ( new TDEAccel( parentWidget ) ),
+ _watcher ( new TDEAccelMenuWatch( _accel, TQT_TQOBJECT(parentWidget) ) )
{
// we need an instance
setInstance( karmPartFactory::instance() );
@@ -108,7 +108,7 @@ void karmPart::slotSelectionChanged()
void karmPart::makeMenus()
{
- KAction
+ TDEAction
*actionKeyBindings,
*actionNew,
*actionNewSub;
@@ -121,84 +121,84 @@ void karmPart::makeMenus()
TQT_SLOT(showDialog()),
actionCollection() );
(void) KStdAction::save( this, TQT_SLOT( save() ), actionCollection() );
- KAction* actionStartNewSession = new KAction( i18n("Start &New Session"),
+ TDEAction* actionStartNewSession = new TDEAction( i18n("Start &New Session"),
0,
TQT_TQOBJECT(this),
TQT_SLOT( startNewSession() ),
actionCollection(),
"start_new_session");
- KAction* actionResetAll = new KAction( i18n("&Reset All Times"),
+ TDEAction* actionResetAll = new TDEAction( i18n("&Reset All Times"),
0,
TQT_TQOBJECT(this),
TQT_SLOT( resetAllTimes() ),
actionCollection(),
"reset_all_times");
- actionStart = new KAction( i18n("&Start"),
+ actionStart = new TDEAction( i18n("&Start"),
TQString::fromLatin1("1rightarrow"), Key_S,
TQT_TQOBJECT(_taskView),
TQT_SLOT( startCurrentTimer() ), actionCollection(),
"start");
- actionStop = new KAction( i18n("S&top"),
+ actionStop = new TDEAction( i18n("S&top"),
TQString::fromLatin1("stop"), 0,
TQT_TQOBJECT(_taskView),
TQT_SLOT( stopCurrentTimer() ), actionCollection(),
"stop");
- actionStopAll = new KAction( i18n("Stop &All Timers"),
+ actionStopAll = new TDEAction( i18n("Stop &All Timers"),
Key_Escape,
TQT_TQOBJECT(_taskView),
TQT_SLOT( stopAllTimers() ), actionCollection(),
"stopAll");
actionStopAll->setEnabled(false);
- actionNew = new KAction( i18n("&New..."),
+ actionNew = new TDEAction( i18n("&New..."),
TQString::fromLatin1("filenew"), CTRL+Key_N,
TQT_TQOBJECT(_taskView),
TQT_SLOT( newTask() ), actionCollection(),
"new_task");
- actionNewSub = new KAction( i18n("New &Subtask..."),
+ actionNewSub = new TDEAction( i18n("New &Subtask..."),
TQString::fromLatin1("tdemultiple"), CTRL+ALT+Key_N,
TQT_TQOBJECT(_taskView),
TQT_SLOT( newSubTask() ), actionCollection(),
"new_sub_task");
- actionDelete = new KAction( i18n("&Delete"),
+ actionDelete = new TDEAction( i18n("&Delete"),
TQString::fromLatin1("editdelete"), Key_Delete,
TQT_TQOBJECT(_taskView),
TQT_SLOT( deleteTask() ), actionCollection(),
"delete_task");
- actionEdit = new KAction( i18n("&Edit..."),
+ actionEdit = new TDEAction( i18n("&Edit..."),
TQString::fromLatin1("edit"), CTRL + Key_E,
TQT_TQOBJECT(_taskView),
TQT_SLOT( editTask() ), actionCollection(),
"edit_task");
-// actionAddComment = new KAction( i18n("&Add Comment..."),
+// actionAddComment = new TDEAction( i18n("&Add Comment..."),
// TQString::fromLatin1("document"),
// CTRL+ALT+Key_E,
// TQT_TQOBJECT(_taskView),
// TQT_SLOT( addCommentToTask() ),
// actionCollection(),
// "add_comment_to_task");
- actionMarkAsComplete = new KAction( i18n("&Mark as Complete"),
+ actionMarkAsComplete = new TDEAction( i18n("&Mark as Complete"),
TQString::fromLatin1("document"),
CTRL+Key_M,
TQT_TQOBJECT(_taskView),
TQT_SLOT( markTaskAsComplete() ),
actionCollection(),
"mark_as_complete");
- actionMarkAsIncomplete = new KAction( i18n("&Mark as Incomplete"),
+ actionMarkAsIncomplete = new TDEAction( i18n("&Mark as Incomplete"),
TQString::fromLatin1("document"),
CTRL+Key_M,
TQT_TQOBJECT(_taskView),
TQT_SLOT( markTaskAsIncomplete() ),
actionCollection(),
"mark_as_incomplete");
- actionClipTotals = new KAction( i18n("&Copy Totals to Clipboard"),
+ actionClipTotals = new TDEAction( i18n("&Copy Totals to Clipboard"),
TQString::fromLatin1("klipper"),
CTRL+Key_C,
TQT_TQOBJECT(_taskView),
TQT_SLOT( clipTotals() ),
actionCollection(),
"clip_totals");
- actionClipHistory = new KAction( i18n("Copy &History to Clipboard"),
+ actionClipHistory = new TDEAction( i18n("Copy &History to Clipboard"),
TQString::fromLatin1("klipper"),
CTRL+ALT+Key_C,
TQT_TQOBJECT(_taskView),
@@ -206,24 +206,24 @@ void karmPart::makeMenus()
actionCollection(),
"clip_history");
- new KAction( i18n("Import &Legacy Flat File..."), 0,
+ new TDEAction( i18n("Import &Legacy Flat File..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(loadFromFlatFile()), actionCollection(),
"import_flatfile");
- new KAction( i18n("&Export to CSV File..."), 0,
+ new TDEAction( i18n("&Export to CSV File..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(exportcsvFile()), actionCollection(),
"export_csvfile");
- new KAction( i18n("Export &History to CSV File..."), 0,
+ new TDEAction( i18n("Export &History to CSV File..."), 0,
TQT_TQOBJECT(this), TQT_SLOT(exportcsvHistory()), actionCollection(),
"export_csvhistory");
- new KAction( i18n("Import Tasks From &Planner..."), 0,
+ new TDEAction( i18n("Import Tasks From &Planner..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(importPlanner()), actionCollection(),
"import_planner");
- new KAction( i18n("Configure KArm..."), 0,
+ new TDEAction( i18n("Configure KArm..."), 0,
TQT_TQOBJECT(_preferences), TQT_SLOT(showDialog()), actionCollection(),
"configure_karm");
/*
- new KAction( i18n("Import E&vents"), 0,
+ new TDEAction( i18n("Import E&vents"), 0,
_taskView,
TQT_SLOT( loadFromKOrgEvents() ), actionCollection(),
"import_korg_events");
@@ -301,7 +301,7 @@ void karmPart::setReadWrite(bool rw)
void karmPart::setModified(bool modified)
{
// get a handle on our Save action and make sure it is valid
- KAction *save = actionCollection()->action(KStdAction::stdName(KStdAction::Save));
+ TDEAction *save = actionCollection()->action(KStdAction::stdName(KStdAction::Save));
if (!save)
return;
diff --git a/karm/karm_part.h b/karm/karm_part.h
index 444b6f428..22a63cff1 100644
--- a/karm/karm_part.h
+++ b/karm/karm_part.h
@@ -8,8 +8,8 @@
#include "reportcriteria.h"
#include <tqlistview.h>
-class KAccel;
-class KAccelMenuWatch;
+class TDEAccel;
+class TDEAccelMenuWatch;
class KarmTray;
class TQWidget;
class TQPainter;
@@ -38,22 +38,22 @@ class karmPart : public KParts::ReadWritePart, virtual public KarmDCOPIface
TQString _hasTask( Task* task, const TQString &taskname ) const;
Task* _hasUid( Task* task, const TQString &uid ) const;
- KAccel* _accel;
- KAccelMenuWatch* _watcher;
+ TDEAccel* _accel;
+ TDEAccelMenuWatch* _watcher;
TaskView* _taskView;
Preferences* _preferences;
KarmTray* _tray;
- KAction* actionStart;
- KAction* actionStop;
- KAction* actionStopAll;
- KAction* actionDelete;
- KAction* actionEdit;
-// KAction* actionAddComment;
- KAction* actionMarkAsComplete;
- KAction* actionMarkAsIncomplete;
- KAction* actionPreferences;
- KAction* actionClipTotals;
- KAction* actionClipHistory;
+ TDEAction* actionStart;
+ TDEAction* actionStop;
+ TDEAction* actionStopAll;
+ TDEAction* actionDelete;
+ TDEAction* actionEdit;
+// TDEAction* actionAddComment;
+ TDEAction* actionMarkAsComplete;
+ TDEAction* actionMarkAsIncomplete;
+ TDEAction* actionPreferences;
+ TDEAction* actionClipTotals;
+ TDEAction* actionClipHistory;
TQString m_error[ KARM_MAX_ERROR_NO + 1 ];
friend class KarmTray;
diff --git a/karm/main.cpp b/karm/main.cpp
index a40b7e396..fd81d5a7e 100644
--- a/karm/main.cpp
+++ b/karm/main.cpp
@@ -79,7 +79,7 @@ int main( int argc, char *argv[] )
myApp.setMainWidget( mainWindow );
- if (kapp->isRestored() && KMainWindow::canBeRestored( 1 ))
+ if (kapp->isRestored() && TDEMainWindow::canBeRestored( 1 ))
mainWindow->restore( 1, false );
else
mainWindow->show();
diff --git a/karm/mainwindow.cpp b/karm/mainwindow.cpp
index dc9b3344a..6bfbcc32c 100644
--- a/karm/mainwindow.cpp
+++ b/karm/mainwindow.cpp
@@ -37,8 +37,8 @@
MainWindow::MainWindow( const TQString &icsfile )
: DCOPObject ( "KarmDCOPIface" ),
KParts::MainWindow(0,TQt::WStyle_ContextHelp),
- _accel ( new KAccel( this ) ),
- _watcher ( new KAccelMenuWatch( _accel, TQT_TQOBJECT(this) ) ),
+ _accel ( new TDEAccel( this ) ),
+ _watcher ( new TDEAccelMenuWatch( _accel, TQT_TQOBJECT(this) ) ),
_totalSum ( 0 ),
_sessionSum( 0 )
{
@@ -246,7 +246,7 @@ void MainWindow::resetAllTimes()
void MainWindow::makeMenus()
{
- KAction
+ TDEAction
*actionKeyBindings,
*actionNew,
*actionNewSub;
@@ -259,77 +259,77 @@ void MainWindow::makeMenus()
TQT_SLOT(showDialog()),
actionCollection() );
(void) KStdAction::save( TQT_TQOBJECT(this), TQT_SLOT( save() ), actionCollection() );
- KAction* actionStartNewSession = new KAction( i18n("Start &New Session"),
+ TDEAction* actionStartNewSession = new TDEAction( i18n("Start &New Session"),
0,
TQT_TQOBJECT(this),
TQT_SLOT( startNewSession() ),
actionCollection(),
"start_new_session");
- KAction* actionResetAll = new KAction( i18n("&Reset All Times"),
+ TDEAction* actionResetAll = new TDEAction( i18n("&Reset All Times"),
0,
TQT_TQOBJECT(this),
TQT_SLOT( resetAllTimes() ),
actionCollection(),
"reset_all_times");
- actionStart = new KAction( i18n("&Start"),
+ actionStart = new TDEAction( i18n("&Start"),
TQString::fromLatin1("1rightarrow"), Key_S,
TQT_TQOBJECT(_taskView),
TQT_SLOT( startCurrentTimer() ), actionCollection(),
"start");
- actionStop = new KAction( i18n("S&top"),
+ actionStop = new TDEAction( i18n("S&top"),
TQString::fromLatin1("stop"), Key_S,
TQT_TQOBJECT(_taskView),
TQT_SLOT( stopCurrentTimer() ), actionCollection(),
"stop");
- actionStopAll = new KAction( i18n("Stop &All Timers"),
+ actionStopAll = new TDEAction( i18n("Stop &All Timers"),
Key_Escape,
TQT_TQOBJECT(_taskView),
TQT_SLOT( stopAllTimers() ), actionCollection(),
"stopAll");
actionStopAll->setEnabled(false);
- actionNew = new KAction( i18n("&New..."),
+ actionNew = new TDEAction( i18n("&New..."),
TQString::fromLatin1("filenew"), CTRL+Key_N,
TQT_TQOBJECT(_taskView),
TQT_SLOT( newTask() ), actionCollection(),
"new_task");
- actionNewSub = new KAction( i18n("New &Subtask..."),
+ actionNewSub = new TDEAction( i18n("New &Subtask..."),
TQString::fromLatin1("tdemultiple"), CTRL+ALT+Key_N,
TQT_TQOBJECT(_taskView),
TQT_SLOT( newSubTask() ), actionCollection(),
"new_sub_task");
- actionDelete = new KAction( i18n("&Delete"),
+ actionDelete = new TDEAction( i18n("&Delete"),
TQString::fromLatin1("editdelete"), Key_Delete,
TQT_TQOBJECT(_taskView),
TQT_SLOT( deleteTask() ), actionCollection(),
"delete_task");
- actionEdit = new KAction( i18n("&Edit..."),
+ actionEdit = new TDEAction( i18n("&Edit..."),
TQString::fromLatin1("edit"), CTRL + Key_E,
TQT_TQOBJECT(_taskView),
TQT_SLOT( editTask() ), actionCollection(),
"edit_task");
-// actionAddComment = new KAction( i18n("&Add Comment..."),
+// actionAddComment = new TDEAction( i18n("&Add Comment..."),
// TQString::fromLatin1("document"),
// CTRL+ALT+Key_E,
// TQT_TQOBJECT(_taskView),
// TQT_SLOT( addCommentToTask() ),
// actionCollection(),
// "add_comment_to_task");
- actionMarkAsComplete = new KAction( i18n("&Mark as Complete"),
+ actionMarkAsComplete = new TDEAction( i18n("&Mark as Complete"),
TQString::fromLatin1("document"),
CTRL+Key_M,
TQT_TQOBJECT(_taskView),
TQT_SLOT( markTaskAsComplete() ),
actionCollection(),
"mark_as_complete");
- actionMarkAsIncomplete = new KAction( i18n("&Mark as Incomplete"),
+ actionMarkAsIncomplete = new TDEAction( i18n("&Mark as Incomplete"),
TQString::fromLatin1("document"),
CTRL+Key_M,
TQT_TQOBJECT(_taskView),
TQT_SLOT( markTaskAsIncomplete() ),
actionCollection(),
"mark_as_incomplete");
- actionClipTotals = new KAction( i18n("&Copy Totals to Clipboard"),
+ actionClipTotals = new TDEAction( i18n("&Copy Totals to Clipboard"),
TQString::fromLatin1("klipper"),
CTRL+Key_C,
TQT_TQOBJECT(_taskView),
@@ -337,14 +337,14 @@ void MainWindow::makeMenus()
actionCollection(),
"clip_totals");
// actionClipTotals will never be used again, overwrite it
- actionClipTotals = new KAction( i18n("&Copy Session Time to Clipboard"),
+ actionClipTotals = new TDEAction( i18n("&Copy Session Time to Clipboard"),
TQString::fromLatin1("klipper"),
0,
TQT_TQOBJECT(_taskView),
TQT_SLOT( clipSession() ),
actionCollection(),
"clip_session");
- actionClipHistory = new KAction( i18n("Copy &History to Clipboard"),
+ actionClipHistory = new TDEAction( i18n("Copy &History to Clipboard"),
TQString::fromLatin1("klipper"),
CTRL+ALT+Key_C,
TQT_TQOBJECT(_taskView),
@@ -352,21 +352,21 @@ void MainWindow::makeMenus()
actionCollection(),
"clip_history");
- new KAction( i18n("Import &Legacy Flat File..."), 0,
+ new TDEAction( i18n("Import &Legacy Flat File..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(loadFromFlatFile()), actionCollection(),
"import_flatfile");
- new KAction( i18n("&Export to CSV File..."), 0,
+ new TDEAction( i18n("&Export to CSV File..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(exportcsvFile()), actionCollection(),
"export_csvfile");
- new KAction( i18n("Export &History to CSV File..."), 0,
+ new TDEAction( i18n("Export &History to CSV File..."), 0,
TQT_TQOBJECT(this), TQT_SLOT(exportcsvHistory()), actionCollection(),
"export_csvhistory");
- new KAction( i18n("Import Tasks From &Planner..."), 0,
+ new TDEAction( i18n("Import Tasks From &Planner..."), 0,
TQT_TQOBJECT(_taskView), TQT_SLOT(importPlanner()), actionCollection(),
"import_planner");
/*
- new KAction( i18n("Import E&vents"), 0,
+ new TDEAction( i18n("Import E&vents"), 0,
_taskView,
TQT_SLOT( loadFromKOrgEvents() ), actionCollection(),
"import_korg_events");
@@ -467,7 +467,7 @@ bool MainWindow::queryClose()
hide();
return false;
}
- return KMainWindow::queryClose();
+ return TDEMainWindow::queryClose();
}
void MainWindow::contextMenuRequest( TQListViewItem*, const TQPoint& point, int )
diff --git a/karm/mainwindow.h b/karm/mainwindow.h
index ba1194f4a..c1504e98f 100644
--- a/karm/mainwindow.h
+++ b/karm/mainwindow.h
@@ -7,8 +7,8 @@
#include <karmdcopiface.h>
#include "reportcriteria.h"
-class KAccel;
-class KAccelMenuWatch;
+class TDEAccel;
+class TDEAccelMenuWatch;
class KarmTray;
class TQListViewItem;
class TQPoint;
@@ -33,23 +33,23 @@ class MainWindow : public KParts::MainWindow, virtual public KarmDCOPIface
TQString _hasTask( Task* task, const TQString &taskname ) const;
Task* _hasUid( Task* task, const TQString &uid ) const;
- KAccel* _accel;
- KAccelMenuWatch* _watcher;
+ TDEAccel* _accel;
+ TDEAccelMenuWatch* _watcher;
TaskView* _taskView;
long _totalSum;
long _sessionSum;
Preferences* _preferences;
KarmTray* _tray;
- KAction* actionStart;
- KAction* actionStop;
- KAction* actionStopAll;
- KAction* actionDelete;
- KAction* actionEdit;
- KAction* actionMarkAsComplete;
- KAction* actionMarkAsIncomplete;
- KAction* actionPreferences;
- KAction* actionClipTotals;
- KAction* actionClipHistory;
+ TDEAction* actionStart;
+ TDEAction* actionStop;
+ TDEAction* actionStopAll;
+ TDEAction* actionDelete;
+ TDEAction* actionEdit;
+ TDEAction* actionMarkAsComplete;
+ TDEAction* actionMarkAsIncomplete;
+ TDEAction* actionPreferences;
+ TDEAction* actionClipTotals;
+ TDEAction* actionClipHistory;
TQString m_error[ KARM_MAX_ERROR_NO + 1 ];
friend class KarmTray;
diff --git a/karm/taskview.h b/karm/taskview.h
index 64b4d3de2..db00f5b16 100644
--- a/karm/taskview.h
+++ b/karm/taskview.h
@@ -23,7 +23,7 @@ class TQTextStream;
class TQTimer;
class KMenuBar;
-class KToolBar;
+class TDEToolBar;
class DesktopTracker;
class EditTaskDialog;
@@ -39,7 +39,7 @@ using namespace KCal;
* Container and interface for the tasks.
*/
-class TaskView : public KListView
+class TaskView : public TDEListView
{
Q_OBJECT
diff --git a/karm/taskviewwhatsthis.cpp b/karm/taskviewwhatsthis.cpp
index 164023f2a..4cc9f7513 100644
--- a/karm/taskviewwhatsthis.cpp
+++ b/karm/taskviewwhatsthis.cpp
@@ -17,7 +17,7 @@
TaskViewWhatsThis::TaskViewWhatsThis( TQWidget* qw )
: TQWhatsThis( qw )
{
- _listView=(KListView *) qw;
+ _listView=(TDEListView *) qw;
}
TaskViewWhatsThis::~TaskViewWhatsThis()
diff --git a/karm/taskviewwhatsthis.h b/karm/taskviewwhatsthis.h
index 1742c58db..1bea3497c 100644
--- a/karm/taskviewwhatsthis.h
+++ b/karm/taskviewwhatsthis.h
@@ -27,6 +27,6 @@ public:
TQString text ( const TQPoint & );
private:
- KListView* _listView; // stores the associated listview for column widths
+ TDEListView* _listView; // stores the associated listview for column widths
};
#endif
diff --git a/karm/tray.h b/karm/tray.h
index e9b537b9b..134e34fa6 100644
--- a/karm/tray.h
+++ b/karm/tray.h
@@ -19,7 +19,7 @@ class TQTimer;
class KSystemTray;
class MainWindow;
// experiment
-// class KPopupMenu;
+// class TDEPopupMenu;
class KarmTray : public KSystemTray
{
@@ -51,7 +51,7 @@ class KarmTray : public KSystemTray
void insertTitle(TQString title);
private:
- KPopupMenu *trayPopupMenu;
+ TDEPopupMenu *trayPopupMenu;
TQPopupMenu *trayPopupMenu2;
*/
};
diff --git a/karm/kaccelmenuwatch.cpp b/karm/kaccelmenuwatch.cpp
index ddabb1d86..4b5952848 100644
--- a/karm/kaccelmenuwatch.cpp
+++ b/karm/kaccelmenuwatch.cpp
@@ -1,5 +1,5 @@
/*
* kaccelmenuwatch.cpp -- Implementation of class KAccelMenuWatch.
* Author: Sirtaj Singh Kang
* Generated: Thu Jan 7 15:05:26 EST 1999
*/
@@ -9,7 +9,7 @@
#include "kaccelmenuwatch.h"
-KAccelMenuWatch::KAccelMenuWatch( KAccel *accel, TQObject *parent )
+TDEAccelMenuWatch::TDEAccelMenuWatch( TDEAccel *accel, TQObject *parent )
: TQObject( parent ),
_accel( accel ),
_menu ( 0 )
@@ -18,7 +18,7 @@ KAccelMenuWatch::KAccelMenuWatch( KAccel *accel, TQObject *parent )
_menuList.setAutoDelete( false );
}
-void KAccelMenuWatch::setMenu( TQPopupMenu *menu )
+void TDEAccelMenuWatch::setMenu( TQPopupMenu *menu )
{
assert( menu );
@@ -33,19 +33,19 @@ void KAccelMenuWatch::setMenu( TQPopupMenu *menu )
_menu = menu;
}
-void KAccelMenuWatch::connectAccel( int itemId, const char *action )
+void TDEAccelMenuWatch::connectAccel( int itemId, const char *action )
{
AccelItem *item = newAccelItem( _menu, itemId, StringAccel ) ;
item->action = TQString::fromLocal8Bit( action );
}
-void KAccelMenuWatch::connectAccel( int itemId, KStdAccel::StdAccel accel )
+void TDEAccelMenuWatch::connectAccel( int itemId, TDEStdAccel::StdAccel accel )
{
AccelItem *item = newAccelItem( _menu, itemId, StdAccel ) ;
item->stdAction = accel;
}
-void KAccelMenuWatch::updateMenus()
+void TDEAccelMenuWatch::updateMenus()
{
assert( _accel != 0 );
@@ -60,7 +60,7 @@ void KAccelMenuWatch::updateMenus()
item->menu->setAccel( _accel->shortcut( item->action ).keyCodeQt(), item->itemId );
break;
case StdAccel:
- item->menu->setAccel( KStdAccel::shortcut( item->stdAction ).keyCodeQt(), item->itemId );
+ item->menu->setAccel( TDEStdAccel::shortcut( item->stdAction ).keyCodeQt(), item->itemId );
break;
default:
break;
@@ -69,7 +69,7 @@ void KAccelMenuWatch::updateMenus()
}
-void KAccelMenuWatch::removeDeadMenu()
+void TDEAccelMenuWatch::removeDeadMenu()
{
TQPopupMenu *sdr = (TQPopupMenu *) sender();
assert( sdr );
@@ -96,7 +96,7 @@ loop:
return;
}
-KAccelMenuWatch::AccelItem *KAccelMenuWatch::newAccelItem( TQPopupMenu *,
+TDEAccelMenuWatch::AccelItem *TDEAccelMenuWatch::newAccelItem( TQPopupMenu *,
int itemId, AccelType type )
{
AccelItem *item = new AccelItem;
@@ -1,5 +1,5 @@
/*
-* kaccelmenuwatch.cpp -- Implementation of class KAccelMenuWatch.
+* kaccelmenuwatch.cpp -- Implementation of class TDEAccelMenuWatch.
* Author: Sirtaj Singh Kang
* Generated: Thu Jan 7 15:05:26 EST 1999
diff --git a/karm/kaccelmenuwatch.h b/karm/kaccelmenuwatch.h
index 010d7c46b..388cd06f5 100644
--- a/karm/kaccelmenuwatch.h
+++ b/karm/kaccelmenuwatch.h
@@ -1,5 +1,5 @@
/*
* kaccelmenuwatch.h -- Declaration of class KAccelMenuWatch.
* Generated by newclass on Thu Jan 7 15:05:26 EST 1999.
*/
#ifndef KARM_K_ACCEL_MENU_WATCH_H
@@ -13,26 +13,26 @@
class TQPopupMenu;
/**
* Easy updating of menu accels when changing a KAccel object.
*
* Since a KAccel object does not keep track of menu items to which it
* is connected, we normally have to manually call
* KAccel::changeMenuAccel() again for each update of the KAccel object.
*
* With KAccelMenuWatch you provide the kaccel object and the menu
* items to which it connects, and if you update the kaccel you just have
- * to call KAccelMenuWatch::updateMenus() and the menu items will be updated.
+ * to call TDEAccelMenuWatch::updateMenus() and the menu items will be updated.
*
* It is safe to delete menus that have connections handled by this class.
* On deletion of a menu, all associated accelerators will be deleted.
*
* Note that you _have_ to call KAccelMenuWatch::updateMenus() after you
* connect the * accelerators, as they are not activated till then.
*
* @author Sirtaj Singh Kang (taj@kde.org)
*/
-class KAccelMenuWatch : public TQObject
+class TDEAccelMenuWatch : public TQObject
{
Q_OBJECT
@@ -48,28 +48,28 @@ class KAccelMenuWatch : public TQObject
// only one of these is used at a time
TQString action;
- KStdAccel::StdAccel stdAction;
+ TDEStdAccel::StdAccel stdAction;
} AccelItem;
- KAccel *_accel;
+ TDEAccel *_accel;
TQPtrList<AccelItem> _accList;
TQPtrList<TQPopupMenu> _menuList;
TQPopupMenu *_menu;
- KAccelMenuWatch::AccelItem *newAccelItem( TQPopupMenu *menu,
+ TDEAccelMenuWatch::AccelItem *newAccelItem( TQPopupMenu *menu,
int itemId, AccelType type );
public:
/**
- * KAccelMenuWatch Constructor
+ * TDEAccelMenuWatch Constructor
*/
- KAccelMenuWatch( KAccel *accel, TQObject *parent = 0 );
+ TDEAccelMenuWatch( TDEAccel *accel, TQObject *parent = 0 );
/**
- * KAccelMenuWatch Destructor
+ * TDEAccelMenuWatch Destructor
*/
- virtual ~KAccelMenuWatch() {}
+ virtual ~TDEAccelMenuWatch() {}
/**
* Set the menu on which connectAccel calls will operate.
@@ -80,7 +80,7 @@ class KAccelMenuWatch : public TQObject
void setMenu( TQPopupMenu *menu );
/**
* Return the last menu set with KAccelMenuWatch::setMenu(TQPopupMenu*),
* or 0 if none has been set.
*/
TQPopupMenu *currentMenu() const { return _menu; }
@@ -94,7 +94,7 @@ class KAccelMenuWatch : public TQObject
/**
* Same as above, but connects to standard accelerators.
*/
- void connectAccel( int itemId, KStdAccel::StdAccel );
+ void connectAccel( int itemId, TDEStdAccel::StdAccel );
public slots:
/**
@@ -107,8 +107,8 @@ class KAccelMenuWatch : public TQObject
void removeDeadMenu();
private:
- KAccelMenuWatch& operator=( const KAccelMenuWatch& );
- KAccelMenuWatch( const KAccelMenuWatch& );
+ TDEAccelMenuWatch& operator=( const TDEAccelMenuWatch& );
+ TDEAccelMenuWatch( const TDEAccelMenuWatch& );
};
#endif // KARM_K_ACCEL_MENU_WATCH_H
@@ -1,5 +1,5 @@
/*
-* kaccelmenuwatch.h -- Declaration of class KAccelMenuWatch.
+* kaccelmenuwatch.h -- Declaration of class TDEAccelMenuWatch.
* Generated by newclass on Thu Jan 7 15:05:26 EST 1999.
*/
@@ -13,26 +13,26 @@
class TQPopupMenu;
/**
- * Easy updating of menu accels when changing a KAccel object.
+ * Easy updating of menu accels when changing a TDEAccel object.
*
@@ -13,26 +13,26 @@
*
- * Since a KAccel object does not keep track of menu items to which it
+ * Since a TDEAccel object does not keep track of menu items to which it
* is connected, we normally have to manually call
@@ -13,26 +13,26 @@
* is connected, we normally have to manually call
- * KAccel::changeMenuAccel() again for each update of the KAccel object.
+ * TDEAccel::changeMenuAccel() again for each update of the TDEAccel object.
*
@@ -13,26 +13,26 @@
*
- * With KAccelMenuWatch you provide the kaccel object and the menu
+ * With TDEAccelMenuWatch you provide the kaccel object and the menu
* items to which it connects, and if you update the kaccel you just have
@@ -13,26 +13,26 @@
* On deletion of a menu, all associated accelerators will be deleted.
*
- * Note that you _have_ to call KAccelMenuWatch::updateMenus() after you
+ * Note that you _have_ to call TDEAccelMenuWatch::updateMenus() after you
* connect the * accelerators, as they are not activated till then.
*
@@ -80,7 +80,7 @@ class KAccelMenuWatch : public TQObject
void setMenu( TQPopupMenu *menu );
/**
- * Return the last menu set with KAccelMenuWatch::setMenu(TQPopupMenu*),
+ * Return the last menu set with TDEAccelMenuWatch::setMenu(TQPopupMenu*),
* or 0 if none has been set.
*/
diff --git a/karm/taskview.cpp b/karm/taskview.cpp
index bcabad37f..14477cf51 100644
--- a/karm/taskview.cpp
+++ b/karm/taskview.cpp
@@ -37,7 +37,7 @@
class DesktopTracker;
-TaskView::TaskView(TQWidget *parent, const char *name, const TQString &icsfile ):KListView(parent,name)
+TaskView::TaskView(TQWidget *parent, const char *name, const TQString &icsfile ):TDEListView(parent,name)
{
_preferences = Preferences::instance( icsfile );
_storage = KarmStorage::instance();
@@ -119,10 +119,10 @@ KarmStorage* TaskView::storage()
void TaskView::contentsMousePressEvent ( TQMouseEvent * e )
{
kdDebug(5970) << "entering contentsMousePressEvent" << endl;
- KListView::contentsMousePressEvent(e);
+ TDEListView::contentsMousePressEvent(e);
Task* task = current_item();
// This checks that there has been a click onto an item,
// not into an empty part of the KListView.
if ( task != 0 && // zero can happen if there is no task
e->pos().y() >= current_item()->itemPos() &&
e->pos().y() < current_item()->itemPos()+current_item()->height() )
@@ -145,7 +145,7 @@ void TaskView::contentsMouseDoubleClickEvent ( TQMouseEvent * e )
// not in the blank space, if yes, stop all other tasks and start the new timer.
{
kdDebug(5970) << "entering contentsMouseDoubleClickEvent" << endl;
- KListView::contentsMouseDoubleClickEvent(e);
+ TDEListView::contentsMouseDoubleClickEvent(e);
Task *task = current_item();
@@ -119,10 +119,10 @@ KarmStorage* TaskView::storage()
Task* task = current_item();
// This checks that there has been a click onto an item,
- // not into an empty part of the KListView.
+ // not into an empty part of the TDEListView.
if ( task != 0 && // zero can happen if there is no task
e->pos().y() >= current_item()->itemPos() &&